Trait PMCRegisterationInfo

pub trait PMCRegisterationInfo {
    // Required methods
    fn registration_details(registrar: &CapeRegistrar) -> Result<(), COBIAError>;
    fn get_uuid() -> CapeUUID;
}
PMCRegisterationInfo is a trait that must be implemented by a struct that implements a PMC. The trait provides the information required to register the PMC with the COBIA registry.

Example

See the example in the unit_operation.rs file in the pmc module

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors