pub fn register_pmc(
pmc_info: &PMCInfo,
writer: &CapeRegistryWriter,
) -> Result<(), COBIAError>Expand description
register a PMC into the COBIA registry
This entry point is called by the the capeRegisterObjects entry point that is generated from the pmc_entry_points! macro to register a PMC