pub fn unregister_pmc(
pmc_info: &PMCInfo,
writer: &CapeRegistryWriter,
) -> Result<(), COBIAError>Expand description
unregister a PMC from the COBIA registry
This entry point is called by the the capeUnregisterObjects entry point that is generated from the pmc_entry_points! macro to register a PMC